@@ -155,6 +155,8 @@ def _download_and_unpack_bundle(bundle_type):
     try:
         LOGGER.info('Unpacking {} to {}'.format(bundle.name, extraction_path))
         archive.extractall(extraction_path)
+    except Exception as err:
+        LOGGER.error('Error when unpacking bundle: {}'.format(err))
     finally:
         archive.close()
 
@@ -386,7 +388,7 @@ def _store_bundle_files(filenames, extraction_path):
                 continue
 
             if sys.platform in ['win32', 'cygwin']:
-                filename = '{}\\{}'.format(extraction_path, filename)
+                filename = '{}\{}'.format(extraction_path, filename)
             else:
                 filename = '{}/{}'.format(extraction_path, filename)
 
